@@ -4,7 +4,7 @@ package Pod::Weaver::PluginBundle::Author::ETHER;
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: A plugin bundle for pod woven by ETHER
 
-our $VERSION = '0.166';
+our $VERSION = '0.167';
 
 use if "$]" >= 5.022, experimental => 're_strict';
 no if "$]" >= 5.031009, feature => 'indirect';
@@ -70,7 +70,7 @@ sub configure {
         ? 'There is also an irc channel available for users of this distribution, at' . "\nL<"
             . do {
                 # try to extract the channel
-                if (my ($network, $channel) = ($distmeta->{resources}{x_IRC} =~ m!(?:://)?(\w+(?:\.\w+)*)/?(#\w+)!)) {
+                if (my ($network, $channel) = ($distmeta->{resources}{x_IRC} =~ m!(?:://)?([\w-]+(?:\.[\w-]+)*)/?(#[\w-]+)!)) {
                     'C<' . $channel . '> on C<' . $network . '>|' . $distmeta->{resources}{x_IRC}
                 }
                 else {
@@ -172,7 +172,7 @@ Pod::Weaver::PluginBundle::Author::ETHER - A plugin bundle for pod woven by ETHE
 
 =head1 VERSION
 
-version 0.166
+version 0.167
 
 =head1 SYNOPSIS
 
