@@ -1,13 +1,21 @@
 use strict;
 use warnings;
-no if "$]" >= 5.031008, feature => 'indirect';
 package {{ $name }};
-# vim: set ts=8 sts=4 sw=4 tw=115 et :
+# vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: ...
 # KEYWORDS: ...
 
 our $VERSION = '{{ $dist->version }}';
 
+use 5.020;
+use strictures 2;
+use stable 0.031 'postderef';
+use experimental 'signatures';
+no autovivification warn => qw(fetch store exists delete);
+use if "$]" >= 5.022, experimental => 're_strict';
+no if "$]" >= 5.031009, feature => 'indirect';
+no if "$]" >= 5.033001, feature => 'multidimensional';
+no if "$]" >= 5.033006, feature => 'bareword_filehandles';
 {{
     ($zilla_plugin) = ($name =~ /^Dist::Zilla::Plugin::(.+)$/g);
 
@@ -19,15 +27,15 @@ use namespace::autoclean;
 
 around dump_config => sub
 {
-    my ($orig, $self) = @_;
-    my $config = $self->$orig;
+  my ($orig, $self) = @_;
+  my $config = $self->$orig;
 
-    $config->{+__PACKAGE__} = {
-        ...,
-        blessed($self) ne __PACKAGE__ ? ( version => $VERSION ) : (),
-    };
+  $config->{+__PACKAGE__} = {
+      ...,
+      blessed($self) ne __PACKAGE__ ? ( version => $VERSION ) : (),
+  };
 
-    return $config;
+  return $config;
 };
 
 
@@ -44,12 +52,12 @@ PLUGIN
 $zilla_plugin ? <<SYNOPSIS
 In your F<dist.ini>:
 
-    [$zilla_plugin]
+  [$zilla_plugin]
 SYNOPSIS
 : <<SYNOPSIS
-    use $name;
+  use $name;
 
-    ...
+  ...
 SYNOPSIS
 }}
 =head1 DESCRIPTION
@@ -58,7 +66,7 @@ SYNOPSIS
 
 =head1 {{ $zilla_plugin ? 'CONFIGURATION OPTIONS' : 'FUNCTIONS/METHODS' }}
 
-=head2 C<foo>
+=head2 foo
 
 ...
 
